beamprofiler.utils.data\_processing.remove\_background
======================================================

.. currentmodule:: beamprofiler.utils.data_processing

.. autofunction:: remove_background